@@ -14,40 +14,42 @@ TEST_CLOUD_URL = 'http://3.137.160.113'
 
 def ping(url: str):
     count = 0
-    received = False
-    while not received and count < 10:
+    while count < 10:
         try:
+            print(url)
             res = requests.get(url)
             assert res.status_code == 200, f"Url returned status code: {res.status_code}"
             assert res.json()['connection'] == "successful", "Connection was not successful"
-            received = True
+            return
         except Exception as e:
             print(e)
         count += 1
+    raise Exception("Unable to get a response from the server: ping")
 
 
-def get_commands(url: str):
+def get_new_commands(domain: str):
     count = 0
     while count < 10:
         try:
-            return requests.get(url)
+            return requests.get(domain + "/command/new")
         except Exception as e:
             print(e)
         count += 1
+    raise Exception("Unable to get a response from the server: get new commands")
 
 
-def set_command_as_executed(url: str, command_id):
+def set_command_as_executed(domain: str, command_id):
     count = 0
-    sent = False
-    while not sent and count < 10:
+    while count < 10:
         try:
-            res = requests.patch(url + f'/command/{command_id}', data={'executed': True})
+            res = requests.patch(domain + f'/command/{command_id}', data={'executed': True})
             if res.status_code != 200:
                 raise Exception("failed to update command as executed [command_id]:", command_id)
-            sent = True
+            return
         except Exception as e:
             print(e)
         count += 1
+    raise Exception("Unable to get a response from the server: update command")
 
 
 def config():
@@ -64,10 +66,10 @@ def config():
 
 def fetch_commands(url: str, interval=10, wait=5):
     while True:
-        res = get_commands(url)
+        res = get_new_commands(url)
         data = []
         try:
-            data = [c for c in res.json() if not c['executed']]
+            data = [c for c in res.json()]
             print(f"FETCHED: {len(data)}")
         except:
             print(f"[Error] Request to api crashed, response: {res = }")
@@ -112,7 +114,7 @@ def run(url: str, interval=10, wait=5):
     admin = Admin(driver=driver, password=password, player_id=admin_id)
     admin.enable_admin()
     admin.execute()
-    for commands in fetch_commands(url + '/command', interval=interval, wait=wait):
+    for commands in fetch_commands(url, interval=interval, wait=wait):
         for command in commands:
             admin.command_list.append(command['code'])
             command['executed'] = True
